==> biome-0.1.2.tgz: package/README.md <==
<p align="center">
    <img alt="Biome - Toolchain of the web"
         src="https://raw.githubusercontent.com/biomejs/resources/main/biome-logo-slogan.svg"
         width="400">
</p>

<div align="center">

[![Discord chat][discord-badge]][discord-url]
[![CI][ci-badge]][ci-url]
[![npm version][npm-badge]][npm-url]
[![VSCode version][vscode-badge]][vscode-url]

[discord-badge]: https://badgen.net/discord/online-members/BypW39g6Yc?icon=discord&label=discord&color=green
[discord-url]: https://discord.gg/BypW39g6Yc
[ci-badge]: https://github.com/biomejs/biome/actions/workflows/main.yml/badge.svg
[ci-url]: https://github.com/biomejs/biome/actions/workflows/main.yml
[npm-badge]: https://badgen.net/npm/v/@biomejs/biome?icon=npm&color=green
[npm-url]: https://www.npmjs.com/package/@biomejs/biome/v/latest
[vscode-badge]: https://badgen.net/vs-marketplace/v/biomejs.biome?label=vscode&icon=visualstudio&color=green
[vscode-url]: https://marketplace.visualstudio.com/items?itemName=biomejs.biome

</div>

**Biome** formats, lints, and transforms your code in a [fraction of a second][biomejs].

**Biome** supports JavaScript, TypeScript, JSON, and CSS.
It aims to support [all main languages][language-support] of modern web development.

**Biome** has sane defaults and requires minimal configuration.
**Biome** helps you as much as possible by displaying detailed and contextualized diagnostics.
Read more about our [project philosophy][biome-philosophy].

**Biome** unifies functionality that has previously been separate tools.
Building upon a shared base allows us to provide a cohesive experience for processing code, displaying errors, parallelizing work, caching, and configuration.

**Biome** is designed to eventually replace [Babel](https://babeljs.io/), [ESLint](https://eslint.org/), [webpack](https://webpack.js.org/), [Prettier](https://prettier.io/), [Jest](https://jestjs.io/), and others.

**Biome** has first-class IDE support,
with a sophisticated parser that represents the source text in full fidelity and top-notch error recovery.

**Biome** is [MIT licensed](https://github.com/biomejs/biome/tree/main/LICENSE) and moderated under the [Contributor Covenant Code of Conduct](https://github.com/biomejs/biome/tree/main/CODE_OF_CONDUCT.md).

## Documentation

Check out our [homepage][biomejs] to learn more about Biome,
or directly head to the [Getting Started guide][getting-started] to start using Biome.

## Technical documentation

Browse Biome's internal [Rust API Documentation] if you're interested to learn more about how Rome works.

[biomejs]: https://biomejs.dev/
[biome-philosophy]: https://biomejs.dev/
[Rust API Documentation]: https://rustdocs.biomejs.dev/
[language-support]: https://biomejs.dev/internals/language_support/
[getting-started]: https://biomejs.dev/guides/getting-started/

==> biome-0.2.0.tgz: package/README.md <==
<p align="center">
    <img alt="Biome - Toolchain of the web"
         src="https://raw.githubusercontent.com/biomejs/resources/main/biome-logo-slogan.svg"
         width="400">
</p>

<div align="center">

[![Discord chat][discord-badge]][discord-url]
[![CI on main][ci-badge]][ci-url]
[![npm version][npm-badge]][npm-url]
[![VSCode version][vscode-badge]][vscode-url]
[![Open VSX version][open-vsx-badge]][open-vsx-url]

[discord-badge]: https://badgen.net/discord/online-members/BypW39g6Yc?icon=discord&label=discord&color=green
[discord-url]: https://discord.gg/BypW39g6Yc
[ci-badge]: https://github.com/biomejs/biome/actions/workflows/main.yml/badge.svg
[ci-url]: https://github.com/biomejs/biome/actions/workflows/main.yml
[npm-badge]: https://badgen.net/npm/v/@biomejs/biome?icon=npm&color=green&label=%40biomejs%2Fbiome
[npm-url]: https://www.npmjs.com/package/@biomejs/biome/v/latest
[vscode-badge]: https://badgen.net/vs-marketplace/v/biomejs.biome?label=vscode&icon=visualstudio&color=green
[vscode-url]: https://marketplace.visualstudio.com/items?itemName=biomejs.biome
[open-vsx-badge]: https://badgen.net/open-vsx/version/biomejs/biome?label=open-vsx&color=green
[open-vsx-url]: https://open-vsx.org/extension/biomejs/biome


</div>

**Biome** formats, lints, and transforms your code in a [fraction of a second][biomejs].

**Biome** supports JavaScript, TypeScript, JSON, and CSS.
It aims to support [all main languages][language-support] of modern web development.

**Biome** has sane defaults and requires minimal configuration.
**Biome** helps you as much as possible by displaying detailed and contextualized diagnostics.
Read more about our [project philosophy][biome-philosophy].

**Biome** unifies functionality that has previously been separate tools.
Building upon a shared base allows us to provide a cohesive experience for processing code, displaying errors, parallelizing work, caching, and configuration.

**Biome** is designed to eventually replace [Babel](https://babeljs.io/), [ESLint](https://eslint.org/), [webpack](https://webpack.js.org/), [Prettier](https://prettier.io/), [Jest](https://jestjs.io/), and others.

**Biome** has first-class IDE support,
with a sophisticated parser that represents the source text in full fidelity and top-notch error recovery.

**Biome** is [MIT licensed](https://github.com/biomejs/biome/tree/main/LICENSE) and moderated under the [Contributor Covenant Code of Conduct](https://github.com/biomejs/biome/tree/main/CODE_OF_CONDUCT.md).

## Documentation

Check out our [homepage][biomejs] to learn more about Biome,
or directly head to the [Getting Started guide][getting-started] to start using Biome.

## Technical documentation

Browse Biome's internal [Rust API Documentation] if you're interested to learn more about how Biome works.

[biomejs]: https://biomejs.dev/
[biome-philosophy]: https://biomejs.dev/
[Rust API Documentation]: https://rustdocs.biomejs.dev/
[language-support]: https://biomejs.dev/internals/language_support/
[getting-started]: https://biomejs.dev/guides/getting-started/
